@@ -35,7 +35,7 @@ import platform as pltf
 import sys as sstm
 import time
 from pathlib import Path as path_t
-from typing import Any, Callable, ClassVar, Dict, Union
+from typing import Any, Callable, ClassVar, TextIO
 
 from rich.color import Color as color_t
 from rich.console import Console as console_t
@@ -46,17 +46,17 @@ try:
     from psutil import Process as process_t
 
     _PROCESS = process_t()
-    _MEGA_UNIT = 1024.0**2
+    _KILO_UNIT = 1024.0
+    _MEGA_UNIT = _KILO_UNIT * 1024.0
     _GIGA_UNIT = _MEGA_UNIT * 1024.0
 except ModuleNotFoundError:
     _PROCESS = None
-    _MEGA_UNIT = _GIGA_UNIT = 0.0
+    _KILO_UNIT = _MEGA_UNIT = _GIGA_UNIT = 0.0
 
 
 # This module is certainly imported early. Therefore, the current time should be close enough to the real start time.
 _START_TIME = time.time()
 
-_TERMINAL_WIDTH = 1000
 _TAB_SIZE = 5  # So that _CONTEXT_SEPARATOR is aligned for all log levels
 _DATE_TIME_LENGTH = 19
 _LOG_LEVEL_LENGTH = 10  # Max length, including _LEVEL_OPENING and _LEVEL_CLOSING
@@ -138,7 +138,7 @@ class _handler_extension:
             record.elapsed_time = ElapsedTime()
         # Re-assign for each handler in case they have different show properties
         if self.show_memory_usage:
-            record.memory_usage = self.MemoryUsage()
+            record.memory_usage = self.FormattedMemoryUsage()
         else:
             record.memory_usage = ""
 
@@ -150,23 +150,22 @@ class _handler_extension:
 
         return formatted, next_lines
 
-    def MemoryUsage(self) -> str:
+    def FormattedMemoryUsage(self) -> str:
         """"""
         if self.show_memory_usage:
             usage = _PROCESS.memory_info().rss
             if usage > self.max_memory_usage:
                 self.max_memory_usage = usage
 
-            if usage > _GIGA_UNIT:
-                return f" :{round(usage / _GIGA_UNIT, 1)}GB"
-            else:
-                return f" :{round(usage / _MEGA_UNIT, 1)}MB"
+            usage, unit = _MemoryWithAutoUnit(usage, 1)
 
-        return ""
+            return f" :{usage}{unit}"
+        else:
+            return ""
 
 
 class console_handler_t(lggg.Handler, _handler_extension):
-    _LEVEL_COLOR: ClassVar[Dict[int, Union[str, style_t]]] = {
+    _LEVEL_COLOR: ClassVar[dict[int, str | style_t]] = {
         lggg.DEBUG: "orchid",
         lggg.INFO: "white",
         lggg.WARNING: "yellow",
@@ -185,9 +184,7 @@ class console_handler_t(lggg.Handler, _handler_extension):
         _handler_extension.__init__(self)
 
         self.setFormatter(self.formatter)
-        self.console = console_t(
-            record=True, force_terminal=True, width=_TERMINAL_WIDTH, tab_size=_TAB_SIZE
-        )
+        self.console = console_t(record=True, force_terminal=True, tab_size=_TAB_SIZE)
 
     def emit(self, record: lggg.LogRecord, /) -> None:
         """"""
@@ -220,7 +217,7 @@ class console_handler_t(lggg.Handler, _handler_extension):
         highlighted.highlight_words((cls._ACTUAL,), style="red")
         highlighted.highlight_words((cls._EXPECTED,), style="green")
 
-        self.console.print(highlighted)
+        self.console.print(highlighted, crop=False, overflow="ignore", highlight=False)
 
 
 class file_handler_t(lggg.FileHandler, _handler_extension):
@@ -260,18 +257,26 @@ def SetShowMemoryUsage(show_memory_usage: bool, /) -> None:
             handler.show_memory_usage = show_memory_usage
 
 
-def AddFileHandler(file: Union[str, path_t], /) -> None:
+def AddFileHandler(path: str | path_t, /) -> None:
     """"""
-    if file.exists():
-        raise ValueError(f"{file}: File already exists")
+    if isinstance(path, str):
+        path = path_t(path)
+    if path.exists():
+        raise ValueError(f"{path}: File already exists")
 
-    LOGGER.addHandler(file_handler_t(file))
+    LOGGER.addHandler(file_handler_t(path))
 
 
-def SaveLOGasHTML(file: Union[str, path_t], /) -> None:
+def SaveLOGasHTML(path: str | path_t | TextIO, /) -> None:
     """"""
-    if file.exists():
-        print(f'Cannot save logging record as HTML: File "{file}" already exists')
+    if isinstance(path, str):
+        path = path_t(path)
+    actual_file = isinstance(path, path_t)
+    if actual_file and path.exists():
+        LOGGER.warning(
+            f'Cannot save logging record as HTML: File "{path}" already exists'
+        )
+        return
 
     console = None
     found = False
@@ -279,11 +284,18 @@ def SaveLOGasHTML(file: Union[str, path_t], /) -> None:
         console = getattr(handler, "console", None)
         if found := isinstance(console, console_t):
             break
-    if found:
-        with open(file, "w") as accessor:
-            accessor.write(console.export_html())
 
-    print("Cannot save logging record as HTML: No handler has a RICH console")
+    if found:
+        html = console.export_html()
+        if actual_file:
+            with open(path, "w") as accessor:
+                accessor.write(html)
+        else:
+            path.write(html)
+    else:
+        LOGGER.warning(
+            "Cannot save logging record as HTML: No handler has a RICH console"
+        )
 
 
 def WhereFunction(function: Any, /) -> str:
@@ -348,6 +360,48 @@ def ElapsedTime() -> str:
     return output
 
 
-def MaximumMemoryUsage() -> int:
+def MaximumMemoryUsage(
+    *, unit: str | None = "a", decimals: int = None
+) -> tuple[int | float, str]:
+    """
+    unit: b or None=bytes, k=kilo, m=mega, g=giga, a=auto
+    """
+    usage = max(_hdr.max_memory_usage for _hdr in LOGGER.handlers)
+
+    if (unit is None) or (unit == "b"):
+        unit = "B"
+    elif unit == "k":
+        usage = _Rounded(usage / _KILO_UNIT, decimals)
+        unit = "KB"
+    elif unit == "m":
+        usage = _Rounded(usage / _MEGA_UNIT, decimals)
+        unit = "MB"
+    elif unit == "g":
+        usage = _Rounded(usage / _GIGA_UNIT, decimals)
+        unit = "GB"
+    elif unit == "a":
+        usage, unit = _MemoryWithAutoUnit(usage, decimals)
+
+    return usage, unit
+
+
+def _MemoryWithAutoUnit(usage: int, decimals: int | None, /) -> tuple[int | float, str]:
     """"""
-    return max(_hdr.max_memory_usage for _hdr in LOGGER.handlers)
+    if usage > _GIGA_UNIT:
+        return _Rounded(usage / _GIGA_UNIT, decimals), "GB"
+
+    if usage > _MEGA_UNIT:
+        return _Rounded(usage / _MEGA_UNIT, decimals), "MB"
+
+    if usage > _KILO_UNIT:
+        return _Rounded(usage / _KILO_UNIT, decimals), "KB"
+
+    return usage, "B"
+
+
+def _Rounded(value: float, decimals: int | None, /) -> int | float:
+    """"""
+    if decimals == 0:
+        decimals = None
+
+    return round(value, ndigits=decimals)
