@@ -31,8 +31,14 @@
 
 from pathlib import Path as path_t
 from tempfile import TemporaryDirectory
-
-from logger_36 import LOGGER, AddFileHandler, MaximumMemoryUsage, SetShowMemoryUsage
+from io import StringIO as fake_file_t
+from logger_36 import (
+    LOGGER,
+    AddFileHandler,
+    MaximumMemoryUsage,
+    SetShowMemoryUsage,
+    SaveLOGasHTML,
+)
 
 
 with TemporaryDirectory() as tmp_folder:
@@ -47,7 +53,15 @@ with TemporaryDirectory() as tmp_folder:
         LogMessage(f"{level.capitalize()} message")
         LogMessage(f"Multi-line\n{level.capitalize()}\nmessage")
 
-    LOGGER.info(f"Max memory usage: {MaximumMemoryUsage()}")
+    LOGGER.info("V" + 30 * "e" + "ry l" + 30 * "o" + "ng line")
+    LOGGER.info("V" + 30 * "e" + "ry l" + 30 * "o" + "ng line...\n...with a newline")
+
+    usage, unit = MaximumMemoryUsage(decimals=1)
+    LOGGER.info(f"Max. memory usage: {usage}{unit}")
 
     content = open(tmp_file, "r").read()
     print(f"\n{content}")
+
+fake_file = fake_file_t()
+SaveLOGasHTML(fake_file)
+print(fake_file.getvalue())
